==> zio-aws-lakeformation_2.13-5.17.129.3-sources.jar: zio/aws/lakeformation/model/GetWorkUnitsRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.lakeformation.model.primitives.{
  GetWorkUnitsRequestQueryIdString,
  Integer,
  Token
}
import scala.jdk.CollectionConverters._
final case class GetWorkUnitsRequest(
    nextToken: Option[Token] = None,
    pageSize: Option[Integer] = None,
    queryId: GetWorkUnitsRequestQueryIdString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest = {
    import GetWorkUnitsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        pageSize.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.pageSize)
      .queryId(
        GetWorkUnitsRequestQueryIdString.unwrap(queryId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly =
    zio.aws.lakeformation.model.GetWorkUnitsRequest.wrap(buildAwsValue())
}
object GetWorkUnitsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.GetWorkUnitsRequest =
      zio.aws.lakeformation.model.GetWorkUnitsRequest(
        nextToken.map(value => value),
        pageSize.map(value => value),
        queryId
      )
    def nextToken: Option[Token]
    def pageSize: Option[Integer]
    def queryId: GetWorkUnitsRequestQueryIdString
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getQueryId: ZIO[Any, Nothing, GetWorkUnitsRequestQueryIdString] =
      ZIO.succeed(queryId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ) extends zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly {
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.lakeformation.model.primitives.Token(value))
    override val pageSize: Option[Integer] = scala
      .Option(impl.pageSize())
      .map(value => zio.aws.lakeformation.model.primitives.Integer(value))
    override val queryId: GetWorkUnitsRequestQueryIdString =
      zio.aws.lakeformation.model.primitives
        .GetWorkUnitsRequestQueryIdString(impl.queryId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ): zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-lakeformation_2.13-5.17.155.1-sources.jar: zio/aws/lakeformation/model/GetWorkUnitsRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.lakeformation.model.primitives.{
  GetWorkUnitsRequestQueryIdString,
  Integer,
  Token
}
import scala.jdk.CollectionConverters._
final case class GetWorkUnitsRequest(
    nextToken: Option[Token] = None,
    pageSize: Option[Integer] = None,
    queryId: GetWorkUnitsRequestQueryIdString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest = {
    import GetWorkUnitsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(pageSize.map(value => value: java.lang.Integer))(
        _.pageSize
      )
      .queryId(
        GetWorkUnitsRequestQueryIdString.unwrap(queryId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly =
    zio.aws.lakeformation.model.GetWorkUnitsRequest.wrap(buildAwsValue())
}
object GetWorkUnitsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.GetWorkUnitsRequest =
      zio.aws.lakeformation.model.GetWorkUnitsRequest(
        nextToken.map(value => value),
        pageSize.map(value => value),
        queryId
      )
    def nextToken: Option[Token]
    def pageSize: Option[Integer]
    def queryId: GetWorkUnitsRequestQueryIdString
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getQueryId: ZIO[Any, Nothing, GetWorkUnitsRequestQueryIdString] =
      ZIO.succeed(queryId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ) extends zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly {
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.lakeformation.model.primitives.Token(value))
    override val pageSize: Option[Integer] =
      scala.Option(impl.pageSize()).map(value => value: Integer)
    override val queryId: GetWorkUnitsRequestQueryIdString =
      zio.aws.lakeformation.model.primitives
        .GetWorkUnitsRequestQueryIdString(impl.queryId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.GetWorkUnitsRequest
  ): zio.aws.lakeformation.model.GetWorkUnitsRequest.ReadOnly = new Wrapper(
    impl
  )
}
